==> cutemaze-1.1.1-2-src.tar.xz: cutemaze-1.1.1/translations/cutemaze_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="170"/>
        <source>Sorry</source>
        <translation>צר לי</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="170"/>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>לא ניתן להטעין משחק קודם. משחק חדש יוחל כעת.</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="445"/>
        <source>%1 elapsed</source>
        <translation>%1 חלפו</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="446"/>
        <source>%1 steps taken</source>
        <translation>נלקחו %1 צעדים</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="447"/>
        <source>%1 of %2 targets remain</source>
        <translation>נותרו %1 מתוך %2 מטרות</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="778"/>
        <source>Success</source>
        <translation>הצלחה</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="795"/>
        <source>Paused</source>
        <translation>מושהה</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <location filename="../src/settings.cpp" line="119"/>
        <source>Shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="123"/>
        <source>Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="126"/>
        <source>Meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="129"/>
        <source>Alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="134"/>
        <source>Super</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="136"/>
        <source>Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="141"/>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="144"/>
        <source>Control</source>
        <translation>בקרה</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="147"/>
        <source>Option</source>
        <translation>אפשרות</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>בחירת שפת יישום:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>נא לאתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="35"/>
        <source>New Game</source>
        <translation>משחק חדש</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="43"/>
        <source>Hunt and Kill</source>
        <translation>צידה והריגה</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="44"/>
        <source>Kruskal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="45"/>
        <source>Prim</source>
        <translation>עדין</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="46"/>
        <source>Recursive Backtracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="47"/>
        <source>Stack</source>
        <translation>מחסנית</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="48"/>
        <source>Stack 2</source>
        <translation>מחסנית 2</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="49"/>
        <source>Stack 3</source>
        <translation>מחסנית 3</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="50"/>
        <source>Stack 4</source>
        <translation>מחסנית 4</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="51"/>
        <source>Stack 5</source>
        <translation>מחסנית 5</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="73"/>
        <source>Algorithm:</source>
        <translation>אלגוריתם:</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="74"/>
        <source>Targets:</source>
        <translation>מטרות:</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="75"/>
        <source>Size:</source>
        <translation>גודל:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <location filename="../src/scores.cpp" line="77"/>
        <source>Hunt and Kill</source>
        <translation>צידה והריגה</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="78"/>
        <source>Kruskal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="79"/>
        <source>Prim</source>
        <translation>עדין</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="80"/>
        <source>Recursive Backtracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="81"/>
        <source>Stack</source>
        <translation>מחסנית</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="82"/>
        <source>Stack 2</source>
        <translation>מחסנית 2</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="83"/>
        <source>Stack 3</source>
        <translation>מחסנית 3</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="84"/>
        <source>Stack 4</source>
        <translation>מחסנית 4</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="85"/>
        <source>Stack 5</source>
        <translation>מחסנית 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <location filename="../src/scores.cpp" line="99"/>
        <source>CuteMaze Scores</source>
        <translation>ניקוד CuteMaze</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Time</source>
        <translation>זמן</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Steps</source>
        <translation>צעדים</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Algorithm</source>
        <translation>אלגוריתם</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="108"/>
        <source>Size</source>
        <translation>גודל</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="160"/>
        <source>Congratulations!</source>
        <translation>ברכותיי!</translation>
    </message>
    <message>
        <location filename="../src/scores.cpp" line="160"/>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>ניקודך צלח אל העשירון העליון.
נא להזין את שמך:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/settings.cpp" line="192"/>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="209"/>
        <source>Game</source>
        <translation>משחק</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="211"/>
        <source>Show where you&apos;ve been</source>
        <translation>הצג היכן היית</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="212"/>
        <source>Show number of steps taken</source>
        <translation>הצג מספר צעדים שנלקחו</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="213"/>
        <source>Show elapsed time</source>
        <translation>הצג זמן שחלף</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="214"/>
        <source>Smooth movement</source>
        <translation>תזוזה חלקה</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="225"/>
        <source>Controls</source>
        <translation>בקרים</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="234"/>
        <source>Move Up:</source>
        <translation>תזוזה מעלה:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="235"/>
        <source>Move Down:</source>
        <translation>תזוזה מטה:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="236"/>
        <source>Move Left:</source>
        <translation>תזוזה שמאלה:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="237"/>
        <source>Move Right:</source>
        <translation>תזוזה ימינה:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="238"/>
        <source>Toggle Flag:</source>
        <translation>מתג דגלון:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="243"/>
        <source>Themes</source>
        <translation>מוטיבים</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="254"/>
        <source>Add</source>
        <translation>הוספה</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="256"/>
        <source>Remove</source>
        <translation>הסרה</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="320"/>
        <source>Select Theme File</source>
        <translation>בחר קובץ מוטיב</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="330"/>
        <location filename="../src/settings.cpp" line="338"/>
        <location filename="../src/settings.cpp" line="371"/>
        <source>Sorry</source>
        <translation>צר לי</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="330"/>
        <source>Unable to create data folder.</source>
        <translation>לא ניתן ליצור תיקיית נתונים.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="338"/>
        <source>Unable to copy theme file.</source>
        <translation>לא ניתן להעתיק קובץ מוטיב.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="367"/>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="367"/>
        <source>Remove the selected theme?</source>
        <translation>להסיר קובץ המוטיב הנבחר?</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="371"/>
        <source>Unable to remove the selected theme.</source>
        <translation>לא ניתן להסיר את המוטיב הנבחר.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="78"/>
        <location filename="../src/window.cpp" line="172"/>
        <source>CuteMaze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="128"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="130"/>
        <source>P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="131"/>
        <source>H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="135"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="137"/>
        <source>View</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="138"/>
        <source>Ctrl++</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="140"/>
        <source>Ctrl+-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="149"/>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="127"/>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="128"/>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="129"/>
        <source>&amp;Pause</source>
        <translation>ה&amp;שהה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="131"/>
        <source>&amp;Hint</source>
        <translation>&amp;רמז</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="133"/>
        <source>High &amp;Scores</source>
        <translation>ניקוד &amp;גבוה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="135"/>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="138"/>
        <source>Zoom &amp;In</source>
        <translation>זום &amp;פנימה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="140"/>
        <source>Zoom &amp;Out</source>
        <translation>זום ה&amp;חוצה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="143"/>
        <source>&amp;Settings</source>
        <translation>ה&amp;גדרות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="144"/>
        <source>Application &amp;Language...</source>
        <translation>&amp;שפת יישום...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="145"/>
        <source>&amp;Preferences...</source>
        <translation>ה&amp;עדפות...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="147"/>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="148"/>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <source>A top-down maze game</source>
        <translation>משחק מבוך מעלה-מטה</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="175"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="176"/>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>הצלמיות נלקחו מן הפרויקט &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="177"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>בשימוש תחת הרשיון &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> cutemaze-1.2.1-1-src.tar.xz: cutemaze-1.2.1/translations/cutemaze_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>מצטערים</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>לא ניתן להטעין משחק קודם. משחק חדש יוחל כעת.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 חלפו</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>נלקחו %1 צעדים</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>נותרו %1 מתוך %2 מטרות</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>הצלחה</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>מושהה</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Super</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>בקרה</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>אפשרות</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>בחירת שפת יישום:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>נא לאתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>משחק חדש</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>צידה והריגה</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>עדין</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>מחסנית</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>מחסנית 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>מחסנית 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>מחסנית 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>מחסנית 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>אלגוריתם:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>מטרות:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>גודל:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>צידה והריגה</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>עדין</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>מחסנית</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>מחסנית 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>מחסנית 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>מחסנית 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>מחסנית 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>ניקוד CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>ניקוד</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>זמן</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>צעדים</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>אלגוריתם</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>גודל</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>ברכותיי!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>ניקודך צלח אל העשירון העליון.
נא להזין את שמך:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>משחק</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>הצג היכן היית</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>הצג מספר צעדים שנלקחו</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>הצג זמן שחלף</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>תזוזה חלקה</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>בקרים</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>תזוזה מעלה:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>תזוזה מטה:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>תזוזה שמאלה:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>תזוזה ימינה:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>מתג דגלון:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>מוטיבים</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>הוספה</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>הסרה</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>בחר קובץ מוטיב</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>צר לי</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>לא ניתן ליצור תיקיית נתונים.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>לא ניתן להעתיק קובץ מוטיב.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>להסיר קובץ המוטיב הנבחר?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>לא ניתן להסיר את המוטיב הנבחר.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;משחק</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>ה&amp;שהה</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;רמז</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>ניקוד &amp;גבוה</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>זום &amp;פנימה</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>זום ה&amp;חוצה</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>ה&amp;גדרות</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;שפת יישום...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>ה&amp;עדפות...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>משחק מבוך מעלה-מטה</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>סמלים מתוך פרויקט &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>בשימוש תחת הרשיון &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
